@@ -10,6 +10,11 @@ profile = {
         "vendor_id": 0x1038,
         "product_id": 0x1824,
         "endpoint": 3,
+    }, {
+        "name": "SteelSeries Rival 3 (firmware v0.37.0.0)",
+        "vendor_id": 0x1038,
+        "product_id": 0x184c,
+        "endpoint": 3,
     }],
 
     "settings": {
@@ -23,6 +28,8 @@ profile = {
             "value_type": "multidpi_range",
             "input_range": [200, 8500, 100],
             "output_range": [4, 0xC5, 2.33],
+            "dpi_length_byte": 1,
+            "count_mode": "number",
             "max_preset_count": 5,
             "default": "800, 1600",
         },
